#'@importFrom utils read.csv write.csv write.table View
#'@docType package
NULL

BASE_URL = "https://opendata.cbs.nl"
API = "ODataApi/odata"
BULK = "ODataFeed/odata"

CATALOG = "ODataCatalog"



